AppPropertyPod<T extends Enum > class
abstract
Properties
$children
→ List <ChangeNotifier >
final inherited
disposable
↔ bool
Whether this Pod is disposable. If false, the Pod will not be disposed
when dispose is called. Instead, it will continue to exist until the
application is closed.
getter/setter pair inherited
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
Whether any listeners are currently registered.
no setter inherited
isDisposed
→ bool
Whether the Pod has been disposed.
no setter inherited
markedAsTemp
↔ bool
Whether this Pod is marked as temporary. Pods marked as temporary are
disposed by consumers like PodBuilder when they are no longer needed.
getter/setter pair inherited
propertyKey
→ String
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
updateValue
→ T?
Gets this Pod's value and notifies any listeners.
no setter inherited
value
↔ T?
Gets this Pod's value without notifying any listeners.
getter/setter pair inherited
values
→ List <T >
final
Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
addSingleExecutionListener (VoidCallback listener )
→ void
Adds a listener to this Pod that is called only once.
inherited
bindChild <T extends ChangeNotifier > (T child )
→ T
Binds the ChangeNotifier child to this (the parent) so that the child
will be disposed when this is disposed.
inherited
call ()
→ T?
Gets this Pod's value and notifies any listeners.
inherited
dispose ()
→ void
Discards any resources used by the object.
inherited
disposeIfMarkedAsTemp ()
→ void
Disposes this Pod and removes all listeners if it is marked as temporary.
inherited
getProperty ()
→ Future <T? >
map <B > (B reducer (T? value ), [List <T? > updateParents (List parentValues , B childValue )? ])
→ ChildPod<T? , B >
Maps this Pod to a new Pod using the specified reducer. Optionally,
provide updateParents to define how parent Pods should be updated when
this Pod changes.
inherited
mapToTemp <B > (B reducer (T? value ), [List <T? > updateParents (List parentValues , B childValue )? ])
→ ChildPod<T? , B >
Maps this Pod to a new temp Pod using the specified reducer. Optionally,
provide updateParents to define how parent Pods should be updated when
this Pod changes.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners ()
→ void
Call all the registered listeners.
inherited
refresh ()
→ Future <void >
Refresh this Pod's value asynchronously and notfies any listeners after
the current build phase to allow you to make state changes during the build
phase.
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
set (T? newValue )
→ Future <void >
Set this Pod's value asynchronously and notfies any listeners after the
current build phase to allow you to make state changes during the build
phase.
inherited
setProperty (T property )
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited
update (T? updater (T? oldValue ) )
→ Future <void >
Update this Pod's value asynchronously and notfies any listeners after the
current build phase to allow you to make state changes during the build
phase.
inherited